package at.ac.uibk.gitsearch.web.rest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import at.ac.uibk.gitsearch.config.ApplicationProperties;
import at.ac.uibk.gitsearch.config.ApplicationProperties.DeploymentInfo;
import at.ac.uibk.gitsearch.service.MessageService;
import at.ac.uibk.gitsearch.service.dto.BroadCastMessageDTO;

/**
 * REST controller to retrieve deployment infos.
 */
@RestController
@RequestMapping("/api")
public class ApplicationInfoResource {

	
    @SuppressWarnings("unused")
	private final Logger log = LoggerFactory.getLogger(ApplicationInfoResource.class);

    private final ApplicationProperties applicationProperties;
    private final MessageService messageService;

    public ApplicationInfoResource(ApplicationProperties applicationProperties, MessageService messageService) {
    	this.applicationProperties = applicationProperties;
    	this.messageService = messageService;
    }

    /**
     * {@code GET  /applicationInfo/deploymentInfo} : get generic deployment info.
     *
     */
    @GetMapping("/applicationInfo/deploymentInfo")
    public ApplicationProperties.DeploymentInfo getApplicationInfo() {
        final DeploymentInfo deploymentInfo = applicationProperties.getDeploymentInfo();
        if(deploymentInfo==null || "${gitBranch}".equals(deploymentInfo.getBranch())) {
        	return new ApplicationProperties.DeploymentInfo(); // application info is not initialized properly! Return an empty info
        }
		return deploymentInfo;
    }
    
    /**
     * {@code GET  /applicationInfo/deploymentInfo} : get generic deployment info.
     *
     */
    @GetMapping("/applicationInfo/broadcastMessages")
    public BroadCastMessageDTO[] getBroadCastMessages() {
    	return messageService.getMessages();
    }

}
