import { ExerciseImportComponent } from 'app/exercise/import/exercise-import.component';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ExerciseService } from 'app/exercise/service/exercise.service';
import { ActivatedRoute } from '@angular/router';
import { of } from 'rxjs';
import { HttpClient, HttpHandler } from '@angular/common/http';
import { ArtemisExerciseInfo } from 'app/shared/model/artemis-exercise-info.model';
import { SearchResultDTO } from 'app/shared/model/search/search-result-dto.model';
import { IExerciseType } from 'app/shared/model/exercise.model';
import { GitlabGroup, IVisibility } from 'app/shared/model/gitlab-group.model';

describe('Component Tests', () => {
  describe('Exercise Import Component', () => {
    let comp: ExerciseImportComponent;
    let fixture: ComponentFixture<ExerciseImportComponent>;
    let service: ExerciseService;

    const exerciseInfoTemplate = new ArtemisExerciseInfo(
      [],
      [],
      false,
      '',
      0,
      '',
      [],
      '',
      '',
      [],
      [],
      new Date(),
      '',
      '',
      {} as SearchResultDTO,
      ['java'],
      '',
      [],
      0,
      [],
      '',
      '',
      '',
      'testExTitle',
      '',
      0,
      0,
      false,
      '',
      ''
    );

    beforeEach(() => {
      TestBed.configureTestingModule({
        imports: [],
        declarations: [ExerciseImportComponent],
        providers: [
          {
            provide: ActivatedRoute,
            useValue: {
              snapshot: {
                params: {
                  token: 'exercise-test-token',
                },
                queryParams: {
                  callback: 'https://callback-url.test',
                },
              },
            },
          },
          ExerciseImportComponent,
          ExerciseService,
          HttpClient,
          HttpHandler,
        ],
      })
        .overrideTemplate(ExerciseImportComponent, '')
        .compileComponents();

      fixture = TestBed.createComponent(ExerciseImportComponent);
      comp = fixture.componentInstance;
      service = TestBed.get(ExerciseService);
    });

    it('Should load on init', () => {
      // GIVEN
      spyOn(service, 'importExerciseInfoFromArtemis').and.returnValue(of(exerciseInfoTemplate));

      // WHEN
      comp.ngOnInit();

      // THEN
      expect(comp.exerciseInfo?.title).toEqual('testExTitle');
      expect(comp.exerciseInfo?.programmingLanguage[0]).toEqual('Java');
    });

    it('Should map metadata values when importing', () => {
      // GIVEN
      comp.exerciseToken = 'TestToken';
      comp.exerciseInfo = exerciseInfoTemplate;
      comp.exerciseInfo.difficulty = 'ADVANCED';
      comp.isPublisherSameAsCreator = true;

      const group: GitlabGroup = {
        id: 1,
        name: 'testGroup',
        path: 'testPath',
        description: '',
        visibility: IVisibility.PUBLIC,
        avatarUrl: '',
        webUrl: '',
        fullName: '',
        fullPath: '',
        parentId: 0,
      };
      spyOn(comp, 'openGitlabPathSelectorModal').and.returnValue(
        new Promise(resolve => {
          resolve(group);
        })
      );
      spyOn(service, 'submitExerciseInfoForImport').and.returnValue(of({}));

      // WHEN
      comp.import();

      // THEN
      expect(comp.exerciseInfo.difficulty).toEqual(comp.exerciseInfo.difficulty.toLowerCase());
      expect(comp.exerciseInfo.publisher).toEqual(comp.exerciseInfo.creator);
    });

    it('Should add and remove creators from list', () => {
      // GIVEN
      comp.exerciseInfo = exerciseInfoTemplate;

      const newPerson = { name: 'newPerson', email: 'person@email', affiliation: 'newAffiliation' };
      const personToRemove = { name: 'personToRemove', email: 'person@toremove', affiliation: '' };

      // WHEN
      comp.addPerson(newPerson, comp.exerciseInfo.creator);
      comp.addPerson(personToRemove, comp.exerciseInfo.creator);
      comp.removePerson(personToRemove, comp.exerciseInfo.creator);

      // THEN
      expect(comp.exerciseInfo?.creator).toEqual([newPerson]);
    });

    it('Should validate form button groups', () => {
      // GIVEN
      comp.exerciseInfo = exerciseInfoTemplate;
      comp.exerciseInfo.keyword = [];
      comp.exerciseInfo.language = [];
      const resultWithErrors = comp.hasValidationErrors();

      comp.exerciseInfo.keyword.push('keyword');
      comp.setLanguage('english');
      const resultWithoutErrors = comp.hasValidationErrors();

      // THEN
      expect(resultWithErrors).toEqual(true);
      expect(resultWithoutErrors).toEqual(false);
    });
  });
});
